@@ -166,9 +166,19 @@ class LocalHandler(object):
         self._cwd = None
 
     def read(self, path):
-        with chdir(self._cwd):
-            with io.open(path, 'r', encoding="utf-8") as f:
-                return f.read()
+        try:
+            with chdir(self._cwd):
+                with io.open(path, 'r', encoding="utf-8") as f:
+                    return f.read()
+        except IOError as e:
+            try:
+                # Check if path could be a notebook passed in as a
+                # string
+                json.loads(path)
+                return path
+            except ValueError:
+                # Propagate the IOError
+                raise e
 
     def listdir(self, path):
         with chdir(self._cwd):
@@ -311,6 +321,15 @@ class GCSHandler(object):
         return path
 
 
+# Hack to make YAML loader not auto-convert datetimes
+# https://stackoverflow.com/a/52312810
+NoDatesSafeLoader = yaml.SafeLoader
+NoDatesSafeLoader.yaml_implicit_resolvers = {
+    k: [r for r in v if r[0] != 'tag:yaml.org,2002:timestamp'] for
+    k, v in NoDatesSafeLoader.yaml_implicit_resolvers.items()
+}
+
+
 # Instantiate a PapermillIO instance and register Handlers.
 papermill_io = PapermillIO()
 papermill_io.register("local", LocalHandler())
@@ -325,7 +344,7 @@ papermill_io.register_entry_points()
 
 def read_yaml_file(path):
     """Reads a YAML file from the location specified at 'path'."""
-    return yaml.load(papermill_io.read(path, ['.json', '.yaml', '.yml']))
+    return yaml.load(papermill_io.read(path, ['.json', '.yaml', '.yml']), Loader=NoDatesSafeLoader)
 
 
 def write_ipynb(nb, path):
